@@ -26,6 +26,10 @@ Copyright_License {
 #include "Hardware/ModelType.hpp"
 #include "Compiler.h"
 
+#ifdef ANDROID
+#include "Android/Product.hpp"
+#endif
+
 #include <tchar.h>
 
 // asset/registration data
@@ -61,21 +65,6 @@ IsDebug()
 #endif
 }
 
-/**
- * Returns whether the application is running on an embedded platform.
- * @return True if host hardware is an embedded platform, False otherwise
- */
-constexpr
-static inline bool
-IsEmbedded()
-{
-#if defined(_WIN32_WCE) || defined(ANDROID)
-  return true;
-#else
-  return false;
-#endif
-}
-
 /**
  * Returns whether the application is running on Pocket PC / Windows
  * CE / Windows Mobile.
@@ -163,6 +152,31 @@ IsAndroid()
 #endif
 }
 
+/**
+ * Returns whether the application is running on a Kobo e-book reader.
+ */
+constexpr
+static inline bool
+IsKobo()
+{
+#ifdef KOBO
+  return true;
+#else
+  return false;
+#endif
+}
+
+/**
+ * Returns whether the application is running on an embedded platform.
+ * @return True if host hardware is an embedded platform, False otherwise
+ */
+constexpr
+static inline bool
+IsEmbedded()
+{
+  return IsAndroid() || IsWindowsCE() || IsKobo();
+}
+
 /**
  * Does this device have little main memory?  On those, some expensive
  * features are disabled.
@@ -208,7 +222,7 @@ constexpr
 static inline bool
 HasTouchScreen()
 {
-  return IsAndroid() || (IsWindowsCE() && !IsAltair());
+  return IsAndroid() || (IsWindowsCE() && !IsAltair()) || IsKobo();
 }
 
 /**
@@ -224,15 +238,85 @@ HasKeyboard()
 }
 
 /**
- * Does this device have a display with colors?
- *
- * XXX not yet implemented!
+ * Does this device have a cursor keys?  These may be used to navigate
+ * in modal dialogs.  Without cursor keys, focused controls do not
+ * need to be highlighted.
  */
+#ifndef ANDROID
 constexpr
+#endif
+static inline bool
+HasCursorKeys()
+{
+  /* we assume that all Windows (CE) devices have cursor keys; some do
+     not, but that's hard to detect */
+
+#ifdef ANDROID
+  return has_cursor_keys;
+#else
+  return !IsKobo();
+#endif
+}
+
+/**
+ * Does this device have a display with colors?
+ */
+#ifdef ANDROID
+gcc_const
+#else
+constexpr
+#endif
 static inline bool
 HasColors()
 {
+#ifdef ANDROID
+  return !IsNookSimpleTouch();
+#elif defined(GREYSCALE)
+  return false;
+#else
+  return !IsKobo();
+#endif
+}
+
+/**
+ * Is dithering black&white used on the display?
+ */
+#if defined(ANDROID) && defined(__arm__)
+gcc_const
+#else
+constexpr
+#endif
+static inline bool
+IsDithered()
+{
+#ifdef DITHER
   return true;
+#elif defined(ANDROID) && defined(__arm__)
+  return is_dithered;
+#else
+  return false;
+#endif
+}
+
+/**
+ * Does this device have an electronic paper screen, such as E-Ink?
+ * Such screens need some special cases, because they are very slow
+ * and show ghosting.  Animations shall be disabled when this function
+ * returns true.
+ */
+#if defined(ANDROID) && defined(__arm__)
+gcc_const
+#else
+constexpr
+#endif
+static inline bool
+HasEPaper()
+{
+#if defined(ANDROID) && defined(__arm__)
+  return IsNookSimpleTouch();
+#else
+  return IsKobo();
+#endif
 }
 
 #endif
