@@ -33,6 +33,7 @@
 
 #include <algorithm>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
 class PortNMEAReader {
@@ -51,13 +52,8 @@ protected:
       /* already full */
       return false;
 
-    const Port::WaitResult wresult =
-      port.WaitRead(env, timeout.GetRemainingOrZero());
-    if (wresult != Port::WaitResult::READY)
-      return false;
-
-    const int nbytes = port.Read(dest.data, dest.length);
-    if (nbytes <= 0)
+    size_t nbytes = port.WaitAndRead(dest.data, dest.length, env, timeout);
+    if (nbytes == 0)
       return false;
 
     buffer.Append(nbytes);
@@ -207,7 +203,7 @@ ReadDate(NMEAInputLine &line, BrokenDate &date)
   if (endptr == p || *endptr != 0)
     return false;
 
-  return date.Plausible();
+  return date.IsPlausible();
 }
 
 static bool
@@ -231,7 +227,7 @@ ReadTime(NMEAInputLine &line, BrokenTime &time)
   if (endptr == p || *endptr != 0)
     return false;
 
-  return time.Plausible();
+  return time.IsPlausible();
 }
 
 static bool
