@@ -54,6 +54,7 @@ IsInternalFile(const TCHAR* str)
     _T("xcsoar-marks.txt"),
     _T("xcsoar-persist.log"),
     _T("xcsoar-startup.log"),
+    _T("xcsoar.log"),
     _T("xcsoar-rasp.dat"),
     NULL
   };
@@ -86,8 +87,8 @@ DataFieldFileReader::Item::~Item()
   free(path);
 }
 
-DataFieldFileReader::DataFieldFileReader(DataAccessCallback OnDataAccess)
-  :DataField(Type::FILE, true, OnDataAccess),
+DataFieldFileReader::DataFieldFileReader(DataFieldListener *listener)
+  :DataField(Type::FILE, true, listener),
    // Set selection to zero
    mValue(0),
    loaded(false), postponed_sort(false),
@@ -294,15 +295,15 @@ DataFieldFileReader::Sort()
      function would require the Item class to be copyable */
 }
 
-ComboList *
-DataFieldFileReader::CreateComboList() const
+ComboList
+DataFieldFileReader::CreateComboList(const TCHAR *reference) const
 {
   /* sorry for the const_cast .. this method keeps the promise of not
      modifying the object, given that one does not count filling the
      (cached) file list as "modification" */
   EnsureLoadedDeconst();
 
-  ComboList *cl = new ComboList();
+  ComboList combo_list;
 
   TCHAR buffer[MAX_PATH];
 
@@ -331,13 +332,13 @@ DataFieldFileReader::CreateComboList() const
       path = buffer;
     }
 
-    cl->Append(i, path);
+    combo_list.Append(i, path);
     if (i == mValue) {
-      cl->ComboPopupItemSavedIndex = i;
+      combo_list.ComboPopupItemSavedIndex = i;
     }
   }
 
-  return cl;
+  return combo_list;
 }
 
 unsigned
