@@ -33,9 +33,7 @@ Copyright_License {
 
 struct DialogLook;
 class Bitmap;
-class ContainerWindow;
 class TabDisplay;
-class TabButton;
 
 /** TabBarControl displays tabs that show/hide the windows
  * associated with each tab.  For example a "Panel" control.
@@ -67,6 +65,9 @@ public:
 
   ~TabBarControl();
 
+  void UpdateLayout(const PixelRect &rc, const PixelRect &tab_rc,
+                    bool vertical);
+
   void SetPageFlippedCallback(PageFlippedCallback _page_flipped_callback) {
     assert(!page_flipped_callback);
     assert(_page_flipped_callback);
@@ -75,7 +76,8 @@ public:
   }
 
 public:
-  unsigned AddTab(Widget *widget, const TCHAR *caption, const Bitmap *bmp = NULL);
+  unsigned AddTab(Widget *widget, const TCHAR *caption,
+                  const Bitmap *bmp=nullptr);
 
 public:
   gcc_pure
@@ -99,6 +101,13 @@ public:
     return pager.GetCurrentWidget();
   }
 
+  /**
+   * Call Widget::SetFocus() on the current widget.
+   */
+  void FocusCurrentWidget() {
+    pager.GetCurrentWidget().SetFocus();
+  }
+
   void ClickPage(unsigned i);
 
   void SetCurrentPage(unsigned i);
@@ -109,6 +118,13 @@ public:
     return pager.Save(changed);
   }
 
+  /**
+   * Pass a key press event to the active widget.
+   */
+  bool InvokeKeyPress(unsigned key_code) {
+    return pager.KeyPress(key_code);
+  }
+
   const PixelRect &GetPagerPosition() const {
     return pager.GetPosition();
   }
