@@ -30,6 +30,12 @@ Copyright_License {
 #include "Screen/Layout.hpp"
 #include "Asset.hpp"
 
+#ifdef ENABLE_OPENGL
+#include "Screen/OpenGL/Texture.hpp"
+#include "Screen/OpenGL/Scope.hpp"
+#include "Screen/OpenGL/Compatibility.hpp"
+#endif
+
 #include <assert.h>
 #include <winuser.h>
 
@@ -150,6 +156,32 @@ TabDisplay::PaintButton(Canvas &canvas, unsigned CaptionStyle,
     const int offsetx = (rc.right - rc.left - bitmap_size.cx / 2) / 2;
     const int offsety = (rc.bottom - rc.top - bitmap_size.cy) / 2;
 
+#ifdef ENABLE_OPENGL
+
+    if (inverse) {
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_COMBINE);
+
+      /* invert the texture color */
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_RGB, GL_REPLACE);
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SRC0_RGB, GL_TEXTURE);
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND0_RGB, GL_ONE_MINUS_SRC_COLOR);
+
+      /* copy the texture alpha */
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_ALPHA, GL_REPLACE);
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SRC0_ALPHA, GL_TEXTURE);
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND0_ALPHA, GL_SRC_ALPHA);
+    } else
+      /* simple copy */
+      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+
+    const GLEnable scope(GL_TEXTURE_2D);
+    const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+    GLTexture &texture = *bmp->GetNative();
+    texture.Bind();
+    texture.Draw(rc.left + offsetx, rc.top + offsety);
+
+#else
     if (inverse) // black background
       canvas.CopyNotOr(rc.left + offsetx,
                        rc.top + offsety,
@@ -165,6 +197,7 @@ TabDisplay::PaintButton(Canvas &canvas, unsigned CaptionStyle,
                       bitmap_size.cy,
                       *bmp,
                       bitmap_size.cx / 2, 0);
+#endif
 
   } else {
 #ifndef USE_GDI
