@@ -22,12 +22,12 @@ Copyright_License {
 */
 
 #include "AirspaceFormatter.hpp"
-
-#include "Engine/Airspace/AbstractAirspace.hpp"
 #include "Engine/Airspace/AirspaceAltitude.hpp"
-#include "Util/StaticString.hpp"
 #include "Units/Units.hpp"
 #include "Units/Descriptor.hpp"
+#include "Util/StringUtil.hpp"
+
+#include <string.h>
 
 void
 AirspaceFormatter::FormatAltitudeShort(TCHAR *buffer,
@@ -38,19 +38,19 @@ AirspaceFormatter::FormatAltitudeShort(TCHAR *buffer,
     if (!positive(altitude.altitude_above_terrain))
       _tcscpy(buffer, _T("GND"));
     else
-      _stprintf(buffer, _T("%d %s AGL"),
-                iround(Units::ToUserAltitude(altitude.altitude_above_terrain)),
-                Units::GetAltitudeName());
+      StringFormatUnsafe(buffer, _T("%d %s AGL"),
+                         iround(Units::ToUserAltitude(altitude.altitude_above_terrain)),
+                         Units::GetAltitudeName());
     break;
 
   case AltitudeReference::STD:
-    _stprintf(buffer, _T("FL%d"), (int)altitude.flight_level);
+    StringFormatUnsafe(buffer, _T("FL%d"), iround(altitude.flight_level));
     break;
 
   case AltitudeReference::MSL:
-    _stprintf(buffer, _T("%d %s"),
-              iround(Units::ToUserAltitude(altitude.altitude)),
-              Units::GetAltitudeName());
+    StringFormatUnsafe(buffer, _T("%d %s"),
+                       iround(Units::ToUserAltitude(altitude.altitude)),
+                       Units::GetAltitudeName());
     break;
 
   case AltitudeReference::NONE:
@@ -70,13 +70,13 @@ AirspaceFormatter::FormatAltitude(TCHAR *buffer,
       Units::GetUserAltitudeUnit() == Unit::METER)
     /* additionally show airspace altitude in feet, because aviation
        charts usually print altitudes in feet */
-    _stprintf(buffer + _tcslen(buffer), _T(" (%d %s)"),
-              iround(Units::ToUserUnit(altitude.altitude, Unit::FEET)),
-              Units::GetUnitName(Unit::FEET));
+    StringFormatUnsafe(buffer + _tcslen(buffer), _T(" (%d %s)"),
+                       iround(Units::ToUserUnit(altitude.altitude, Unit::FEET)),
+                       Units::GetUnitName(Unit::FEET));
 
   if (altitude.reference != AltitudeReference::MSL &&
       positive(altitude.altitude))
-    _stprintf(buffer + _tcslen(buffer), _T(" %d %s"),
-              iround(Units::ToUserAltitude(altitude.altitude)),
-              Units::GetAltitudeName());
+    StringFormatUnsafe(buffer + _tcslen(buffer), _T(" %d %s"),
+                       iround(Units::ToUserAltitude(altitude.altitude)),
+                       Units::GetAltitudeName());
 }
