@@ -364,7 +364,7 @@ MainWindow::ReinitialiseLayout()
     const PixelRect bottom_rect = GetBottomWidgetRect(main_rect,
                                                       bottom_widget);
 
-    if (bottom_widget != nullptr)
+    if (HaveBottomWidget())
       bottom_widget->Move(bottom_rect);
 
     map->Move(GetMapRectAbove(main_rect, bottom_rect));
@@ -633,7 +633,7 @@ bool
 MainWindow::OnKeyDown(unsigned key_code)
 {
   return (widget != nullptr && widget->KeyPress(key_code)) ||
-    (bottom_widget != nullptr && bottom_widget->KeyPress(key_code)) ||
+    (HaveBottomWidget() && bottom_widget->KeyPress(key_code)) ||
     InputEvents::processKey(key_code) ||
     SingleWindow::OnKeyDown(key_code);
 }
@@ -749,7 +749,7 @@ bool MainWindow::OnClose() {
 void
 MainWindow::OnPaint(Canvas &canvas)
 {
-  if (bottom_widget != nullptr && map != nullptr) {
+  if (HaveBottomWidget() && map != nullptr) {
     /* draw a separator between main area and bottom area */
     PixelRect rc = map->GetPosition();
     rc.top = rc.bottom;
@@ -840,9 +840,11 @@ MainWindow::ActivateMap()
     map->Show();
     map->SetFocus();
 
-    if (bottom_widget != nullptr)
+    if (bottom_widget != nullptr) {
+      assert(HaveBottomWidget());
       bottom_widget->Show(GetBottomWidgetRect(GetMainRect(),
                                               bottom_widget));
+    }
 
 #ifndef ENABLE_OPENGL
     if (draw_suspended) {
@@ -887,7 +889,10 @@ MainWindow::KillBottomWidget()
     return;
 
   if (widget == nullptr)
+    /* the bottom widget is only visible below the map, but not below
+       a custom main widget; see HaveBottomWidget() */
     bottom_widget->Hide();
+
   bottom_widget->Unprepare();
   delete bottom_widget;
   bottom_widget = nullptr;
@@ -918,6 +923,8 @@ MainWindow::SetBottomWidget(Widget *_widget)
     bottom_widget->Prepare(*this, bottom_rect);
 
     if (widget == nullptr)
+      /* the bottom widget is only visible below the map, but not
+         below a custom main widget; see HaveBottomWidget() */
       bottom_widget->Show(bottom_rect);
   }
 
@@ -932,6 +939,8 @@ MainWindow::SetWidget(Widget *_widget)
 
   restore_page_pending = false;
 
+  const bool have_bottom_widget = HaveBottomWidget();
+
   /* delete the old widget */
   KillWidget();
 
@@ -947,7 +956,7 @@ MainWindow::SetWidget(Widget *_widget)
 #endif
   }
 
-  if (bottom_widget != nullptr)
+  if (have_bottom_widget)
     bottom_widget->Hide();
 
   widget = _widget;
