@@ -29,14 +29,15 @@ Copyright_License {
 
 struct AttitudeState
 {
-  bool bank_angle_available;
-  bool pitch_angle_available;
-
   /** Estimated bank angle */
   Angle bank_angle;
+  Validity bank_angle_available;
+  bool bank_angle_computed;
 
   /** Estimated pitch angle */
   Angle pitch_angle;
+  Validity pitch_angle_available;
+  bool pitch_angle_computed;
 
   /** Estimated heading */
   Angle heading;
@@ -44,12 +45,22 @@ struct AttitudeState
   bool heading_computed;
 
   void Reset() {
-    bank_angle_available = false;
-    pitch_angle_available = false;
+    bank_angle_available.Clear();
+    bank_angle_computed = false;
+    pitch_angle_available.Clear();
+    pitch_angle_computed = false;
     heading_available.Clear();
     heading_computed = false;
   }
 
+  bool IsBankAngleUseable() const {
+    return bank_angle_available || bank_angle_computed;
+  }
+
+  bool IsPitchAngleUseable() const {
+    return pitch_angle_available || pitch_angle_computed;
+  }
+
   bool IsHeadingUseable() const {
     return heading_available || heading_computed;
   }
