@@ -24,14 +24,12 @@ Copyright_License {
 #include "PlaneFileGlue.hpp"
 #include "Plane.hpp"
 #include "Polar/Parser.hpp"
-#include "Units/System.hpp"
 #include "IO/KeyValueFileReader.hpp"
 #include "IO/KeyValueFileWriter.hpp"
 #include "IO/TextWriter.hpp"
 #include "IO/FileLineReader.hpp"
 #include "Util/NumberParser.hpp"
-
-#include <cstdio>
+#include "LogFile.hpp"
 
 static bool
 ReadPolar(const char *string, Plane &plane)
@@ -143,6 +141,11 @@ bool
 PlaneGlue::ReadFile(Plane &plane, const TCHAR *path)
 {
   FileLineReaderA reader(path);
+  if (reader.error()) {
+    LogFormat(_T("Failed to open plane file: %s"), path);
+    return false;
+  }
+
   KeyValueFileReader kvreader(reader);
   return Read(plane, kvreader);
 }
