@@ -38,6 +38,8 @@ DebugReplay::DebugReplay(NLineReader *_reader)
   calculated.Reset();
 
   flying_computer.Reset();
+
+  wrap_clock.Reset();
 }
 
 DebugReplay::~DebugReplay()
@@ -62,6 +64,7 @@ DebugReplay::Compute()
 {
   computed_basic.Reset();
   (NMEAInfo &)computed_basic = raw_basic;
+  wrap_clock.Normalise(computed_basic);
 
   FeaturesSettings features;
   features.nav_baro_altitude_enabled = true;
@@ -77,19 +80,28 @@ DebugReplay *
 CreateDebugReplay(Args &args)
 {
   if (!args.IsEmpty() && MatchesExtension(args.PeekNext(), ".igc")) {
-    const char *input_file = args.ExpectNext();
-
-    FileLineReaderA *reader = new FileLineReaderA(input_file);
-    if (reader->error()) {
-      delete reader;
-      fprintf(stderr, "Failed to open %s\n", input_file);
-      return NULL;
-    }
-
-    return new DebugReplayIGC(reader);
+    return CreateDebugReplayIGC(args.ExpectNext());
   }
 
-  const tstring driver_name = args.ExpectNextT();
+  const auto driver_name = args.ExpectNextT();
+  const auto input_file = args.ExpectNext();
+  return CreateDebugReplayNMEA(driver_name, input_file);
+}
+
+DebugReplay *
+CreateDebugReplayIGC(const char *input_file) {
+  FileLineReaderA *reader = new FileLineReaderA(input_file);
+  if (reader->error()) {
+    delete reader;
+    fprintf(stderr, "Failed to open %s\n", input_file);
+    return NULL;
+  }
+
+  return new DebugReplayIGC(reader);
+}
+
+DebugReplay *
+CreateDebugReplayNMEA(const tstring &driver_name, const char *input_file) {
 
   const struct DeviceRegister *driver = FindDriverByName(driver_name.c_str());
   if (driver == NULL) {
@@ -97,8 +109,6 @@ CreateDebugReplay(Args &args)
     return NULL;
   }
 
-  const char *input_file = args.ExpectNext();
-
   FileLineReaderA *reader = new FileLineReaderA(input_file);
   if (reader->error()) {
     delete reader;
