@@ -28,8 +28,8 @@ Copyright_License {
 #include "Device/Register.hpp"
 #include "Device/Parser.hpp"
 #include "Device/Driver/FLARM/Device.hpp"
+#include "Device/Config.hpp"
 #include "OS/Args.hpp"
-#include "Profile/DeviceConfig.hpp"
 #include "Util/StringUtil.hpp"
 #include "Util/ConvertString.hpp"
 #include "Operation/ConsoleOperationEnvironment.hpp"
@@ -408,6 +408,14 @@ main(int argc, char **argv)
   }
 
   ConsoleOperationEnvironment env;
+
+  if (!port->WaitConnected(env)) {
+    delete port;
+    DeinitialiseIOThread();
+    fprintf(stderr, "Failed to connect the port\n");
+    return EXIT_FAILURE;
+  }
+
   FlarmDevice flarm(*port);
   RunUI(flarm, env);
 
